using System;
using System.Xml;
using System.Collections.Specialized;

namespace PictureGrabber
{
    public class PgConfig
    {
        #region Field declarations

        public StringCollection sourceDirectories;
        public StringCollection fileMasks;

        public string   connectionString;
        public string   destinationTable;
        public bool     truncateTable;

        public int imageQuality;
        public int imageWidthMax;
        public int imageHeightMax;

        public string errorMessage;

        #endregion

        public PgConfig()
		{
			this.sourceDirectories = new StringCollection();
			this.fileMasks         = new StringCollection();

			this.truncateTable    = false;
			this.destinationTable = "";
			this.connectionString = "";

			this.imageHeightMax   = 0 ;
			this.imageWidthMax    = 0 ;
			this.imageQuality     = 0 ;
		
			this.errorMessage	  = "";
		}

        public bool LoadFromAppConfig()
        {
            try
            {
                System.Collections.IDictionary param;
                param = (System.Collections.IDictionary)System.Configuration.ConfigurationManager.GetSection("tableManager");
                this.connectionString = (string)param["connectionString"];
                this.destinationTable = (string)param["table"];
                string cTruncate = (string)param["truncate"];
                this.truncateTable = cTruncate.ToUpper().Equals("YES");

                param = (System.Collections.IDictionary) System.Configuration.ConfigurationManager.GetSection("imageToolkit");
                this.imageHeightMax = short.Parse((string)param["maxHeight"]);
                this.imageWidthMax  = short.Parse((string)param["maxWidth"]);
                this.imageQuality   = short.Parse((string)param["quality"]);

                this.fileMasks = (StringCollection) System.Configuration.ConfigurationManager.GetSection("fileMasks");

                this.sourceDirectories = (StringCollection) System.Configuration.ConfigurationManager.GetSection("sourceDirectories");

                return true;
            }
            catch (Exception eee)
            {
                this.errorMessage = eee.Message;
                return false;
            }
        }
        
        public void DumpToConsole()
        {
            Console.WriteLine("-------------------------------------------");
            Console.WriteLine("Current configuration values:");
            Console.WriteLine("-------------------------------------------");
            Console.WriteLine("Connection String = {0}", this.connectionString);
            Console.WriteLine("Destination Table = {0}", this.destinationTable);
            Console.WriteLine("Truncate = {0}",          this.truncateTable);
            Console.WriteLine("Image Quality = {0}",     this.imageQuality);
            Console.WriteLine("Image Max Width = {0}",   this.imageWidthMax);
            Console.WriteLine("Image Max Height = {0}",  this.imageHeightMax);
            Console.WriteLine("File masks:");
            foreach (string mask in this.fileMasks)
                Console.WriteLine("   " + mask);
            Console.WriteLine("Source directories:");
            foreach (string dir in this.sourceDirectories)
                Console.WriteLine("   " + dir);
            Console.WriteLine("-------------------------------------------");
        }

    }

    public class StringCollectionSectionHandler : System.Configuration.IConfigurationSectionHandler
    {
        public StringCollectionSectionHandler() { }

        public object Create(object parent, object configContext, XmlNode section)
        {
            StringCollection itemList = new StringCollection();

            foreach (XmlNode child in section.ChildNodes)
            {
                if (child.NodeType == XmlNodeType.Element)
                {
                    itemList.Add(child.InnerText);
                }
            }
            return itemList;
        }
    }




}
